gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: doxygen


From: gnunet
Subject: [taler-exchange] branch master updated: doxygen
Date: Sat, 18 Jan 2020 14:36:52 +0100

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new c8772279 doxygen
c8772279 is described below

commit c87722791debda4961f514d34b32b3f2775eaac9
Author: Christian Grothoff <address@hidden>
AuthorDate: Sat Jan 18 14:36:49 2020 +0100

    doxygen
---
 contrib/microhttpd.tag                             |  6 ++++++
 src/bank-lib/fakebank.c                            |  9 ++++++++-
 src/exchange/taler-exchange-httpd_refresh_melt.h   |  9 +++++----
 src/exchange/taler-exchange-httpd_refresh_reveal.h | 14 +++++++-------
 src/exchange/taler-exchange-httpd_validation.c     |  7 +++----
 src/exchange/taler-exchange-wirewatch.c            |  1 +
 src/exchangedb/exchangedb_fees.c                   |  8 ++++----
 src/include/taler_fakebank_lib.h                   |  9 +++++----
 src/include/taler_mhd_lib.h                        |  2 +-
 src/include/taler_testing_lib.h                    |  3 +--
 src/mhd/mhd_parsing.c                              |  4 ++--
 src/mhd/mhd_responses.c                            |  1 -
 12 files changed, 43 insertions(+), 30 deletions(-)

diff --git a/contrib/microhttpd.tag b/contrib/microhttpd.tag
index b3331b2d..c928dcbd 100644
--- a/contrib/microhttpd.tag
+++ b/contrib/microhttpd.tag
@@ -46,6 +46,12 @@
       <anchorfile>microhttpd.h</anchorfile>
       <arglist></arglist>
     </member>
+    <member kind="define">
+      <type>#define</type>
+      <name>MHD_OPTION_NOTIFY_COMPLETED</name>
+      <anchorfile>microhttpd.h</anchorfile>
+      <arglist></arglist>
+    </member>
     <member kind="typedef">
       <type>int</type>
       <name>MHD_AccessHandlerCallback</name>
diff --git a/src/bank-lib/fakebank.c b/src/bank-lib/fakebank.c
index ea0f23ac..2a264f78 100644
--- a/src/bank-lib/fakebank.c
+++ b/src/bank-lib/fakebank.c
@@ -1394,7 +1394,14 @@ run_mhd (void *cls)
 
 
 /**
- * Start the fake bank.
+ * Start the fake bank.  The fake bank will, like the normal bank, listen for
+ * requests for /admin/add/incoming and /transfer. However, instead of
+ * executing or storing those requests, it will simply allow querying whether
+ * such a request has been made via #TALER_FAKEBANK_check_debit() and
+ * #TALER_FAKEBANK_check_credit() as well as the history API.
+ *
+ * This is useful for writing testcases to check whether the exchange
+ * would have issued the correct wire transfer orders.
  *
  * @param port port to listen to
  * @return NULL on error
diff --git a/src/exchange/taler-exchange-httpd_refresh_melt.h 
b/src/exchange/taler-exchange-httpd_refresh_melt.h
index a938abff..e6c74b3a 100644
--- a/src/exchange/taler-exchange-httpd_refresh_melt.h
+++ b/src/exchange/taler-exchange-httpd_refresh_melt.h
@@ -29,10 +29,11 @@
 
 
 /**
- * Handle a "/refresh/melt" request.  Parses the request into the JSON
- * components and then hands things of to #handle_refresh_melt_json()
- * to validate the melted coins, the signature and execute the melt
- * using TEH_DB_execute_refresh_melt().
+ * Handle a "/refresh/melt" request after the first parsing has
+ * happened.  We now need to validate the coins being melted and the
+ * session signature and then hand things of to execute the melt
+ * operation.  This function parses the JSON arrays and then passes
+ * processing on to #refresh_melt_transaction().
  *
  * @param rh context of the handler
  * @param connection the MHD connection to handle
diff --git a/src/exchange/taler-exchange-httpd_refresh_reveal.h 
b/src/exchange/taler-exchange-httpd_refresh_reveal.h
index cc5ac3f8..fed256e8 100644
--- a/src/exchange/taler-exchange-httpd_refresh_reveal.h
+++ b/src/exchange/taler-exchange-httpd_refresh_reveal.h
@@ -29,13 +29,13 @@
 
 
 /**
- * Handle a "/refresh/reveal" request.  This time, the client reveals
- * the private transfer keys except for the cut-and-choose value
- * returned from "/refresh/commit".  This function parses the revealed
- * keys and secrets and ultimately passes everything to
- * #TEH_DB_execute_refresh_reveal() which will verify that the
- * revealed information is valid then returns the signed refreshed
- * coins.
+ * Handle a "/refresh/reveal" request. This time, the client reveals the
+ * private transfer keys except for the cut-and-choose value returned from
+ * "/refresh/melt".  This function parses the revealed keys and secrets and
+ * ultimately passes everything to #resolve_refresh_reveal_denominations()
+ * which will verify that the revealed information is valid then runs the
+ * transaction in #refresh_reveal_transaction() and finally returns the signed
+ * refreshed coins.
  *
  * @param rh context of the handler
  * @param connection the MHD connection to handle
diff --git a/src/exchange/taler-exchange-httpd_validation.c 
b/src/exchange/taler-exchange-httpd_validation.c
index 79c01716..f5497c3c 100644
--- a/src/exchange/taler-exchange-httpd_validation.c
+++ b/src/exchange/taler-exchange-httpd_validation.c
@@ -16,7 +16,7 @@
 
 /**
  * @file taler-exchange-httpd_validation.c
- * @brief helpers for calling the wire plugins to validate addresses
+ * @brief helpers for getting our wire account information
  * @author Christian Grothoff
  */
 #include "platform.h"
@@ -67,11 +67,10 @@ load_fee (const char *method)
 
 /**
  * Initialize account; checks if @a ai has /wire information, and if so,
- * adds the /wire information (if included) to our responses. Also, if
- * the account is debitable, we try to load the plugin.
+ * adds the /wire information (if included) to our responses.
  *
  * @param cls pointer to `int` to set to #GNUNET_SYSERR on errors
- * @param name name of the plugin to load
+ * @param ai details about the account we should load the wire details for
  */
 static void
 load_account (void *cls,
diff --git a/src/exchange/taler-exchange-wirewatch.c 
b/src/exchange/taler-exchange-wirewatch.c
index 01097482..bce87687 100644
--- a/src/exchange/taler-exchange-wirewatch.c
+++ b/src/exchange/taler-exchange-wirewatch.c
@@ -316,6 +316,7 @@ find_transfers (void *cls);
  * the bank for the transaction history.
  *
  * @param cls closure with the `struct TALER_EXCHANGEDB_Session *`
+ * @param http_status HTTP status code from the server
  * @param ec taler error code
  * @param serial_id identification of the position at which we are querying
  * @param details details about the wire transfer
diff --git a/src/include/taler_fakebank_lib.h b/src/include/taler_fakebank_lib.h
index 017ffd45..1fe83c48 100644
--- a/src/include/taler_fakebank_lib.h
+++ b/src/include/taler_fakebank_lib.h
@@ -34,10 +34,11 @@ struct TALER_FAKEBANK_Handle;
 
 
 /**
- * Start the fake bank.  The fake bank will, like the normal bank,
- * listen for requests for /admin/add/incoming. However, instead of
- * executing or storing those requests, it will simply allow querying
- * whether such a request has been made via #TALER_FAKEBANK_check().
+ * Start the fake bank.  The fake bank will, like the normal bank, listen for
+ * requests for /admin/add/incoming and /transfer. However, instead of
+ * executing or storing those requests, it will simply allow querying whether
+ * such a request has been made via #TALER_FAKEBANK_check_debit() and
+ * #TALER_FAKEBANK_check_credit() as well as the history API.
  *
  * This is useful for writing testcases to check whether the exchange
  * would have issued the correct wire transfer orders.
diff --git a/src/include/taler_mhd_lib.h b/src/include/taler_mhd_lib.h
index fdf60d56..b57239f4 100644
--- a/src/include/taler_mhd_lib.h
+++ b/src/include/taler_mhd_lib.h
@@ -225,7 +225,7 @@ TALER_MHD_reply_static (struct MHD_Connection *connection,
  * (incrementally) process JSON data uploaded to the HTTP
  * server.  It will store the required state in the
  * "connection_cls", which must be cleaned up using
- * #TALER_MHD_post_cleanup_callback().
+ * #TALER_MHD_parse_post_cleanup_callback().
  *
  * @param connection the MHD connection
  * @param con_cls the closure (points to a `struct Buffer *`)
diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index 6af1b6b9..dccb1c2b 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -389,8 +389,7 @@ struct TALER_TESTING_Interpreter
 
   /**
    * Handle to the auditor.  NULL unless specifically initialized
-   * as part of libtalertestingauditor's
-   * #TALER_TESTING_AUDITOR_main_wrapper().
+   * as part of #TALER_TESTING_auditor_setup().
    */
   struct TALER_AUDITOR_Handle *auditor;
 
diff --git a/src/mhd/mhd_parsing.c b/src/mhd/mhd_parsing.c
index 685e0043..21c215a2 100644
--- a/src/mhd/mhd_parsing.c
+++ b/src/mhd/mhd_parsing.c
@@ -38,7 +38,7 @@
  * realizes an MHD POST processor that will (incrementally) process
  * JSON data uploaded to the HTTP server.  It will store the required
  * state in the @a con_cls, which must be cleaned up using
- * #TALER_MHD_post_cleanup_callback().
+ * #TALER_MHD_parse_post_cleanup_callback().
  *
  * @param connection the MHD connection
  * @param con_cls the closure (points to a `struct Buffer *`)
@@ -109,7 +109,7 @@ TALER_MHD_parse_post_json (struct MHD_Connection 
*connection,
  * to clean up our state.
  *
  * @param con_cls value as it was left by
- *        #TALER_MHD_post_json(), to be cleaned up
+ *        #TALER_MHD_parse_post_json(), to be cleaned up
  */
 void
 TALER_MHD_parse_post_cleanup_callback (void *con_cls)
diff --git a/src/mhd/mhd_responses.c b/src/mhd/mhd_responses.c
index d54945c6..aeb3b0b6 100644
--- a/src/mhd/mhd_responses.c
+++ b/src/mhd/mhd_responses.c
@@ -490,7 +490,6 @@ TALER_MHD_reply_agpl (struct MHD_Connection *connection,
  * Function to call to handle the request by sending
  * back static data.
  *
- * @param rh context of the handler
  * @param connection the MHD connection to handle
  * @param http_status status code to return
  * @param mime_type content-type to use

diff --git a/src/exchangedb/exchangedb_fees.c b/src/exchangedb/exchangedb_fees.c
index c025604f..83f4f259 100644
--- a/src/exchangedb/exchangedb_fees.c
+++ b/src/exchangedb/exchangedb_fees.c
@@ -144,12 +144,12 @@ TALER_EXCHANGEDB_fees_read (const struct 
GNUNET_CONFIGURATION_Handle *cfg,
 /**
  * Convert @a af to @a wf.
  *
  * @param method name of the wire method the fees are for
  * @param[in,out] af aggregate fees, host format (updated to round time)
  * @param[out] wf aggregate fees, disk / signature format
  */
 void
-TALER_EXCHANGEDB_fees_2_wf (const char *method,
+TALER_EXCHANGEDB_fees_2_wf (const char *wiremethod,
                             struct TALER_EXCHANGEDB_AggregateFees *af,
                             struct TALER_MasterWireFeePS *wf)
 {
@@ -157,8 +157,8 @@ TALER_EXCHANGEDB_fees_2_wf (const char *method,
   (void) GNUNET_TIME_round_abs (&af->end_date);
   wf->purpose.size = htonl (sizeof (*wf));
   wf->purpose.purpose = htonl (TALER_SIGNATURE_MASTER_WIRE_FEES);
-  GNUNET_CRYPTO_hash (method,
-                      strlen (method) + 1,
+  GNUNET_CRYPTO_hash (wiremethod,
+                      strlen (wiremethod) + 1,
                       &wf->h_wire_method);
   wf->start_date = GNUNET_TIME_absolute_hton (af->start_date);
   wf->end_date = GNUNET_TIME_absolute_hton (af->end_date);
@@ -144,12 +144,12 @@ TALER_EXCHANGEDB_fees_read (const struct 
  * Convert @a af to @a wf.
  *
- * @param method name of the wire method the fees are for
+ * @param wiremethod name of the wire method the fees are for
  * @param[in,out] af aggregate fees, host format (updated to round time)
  * @param[out] wf aggregate fees, disk / signature format
-- 
To stop receiving notification emails like this one, please contact
address@hidden.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]